# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.applicationmodel.datatransfer as windows_applicationmodel_datatransfer
import winrt.windows.foundation as windows_foundation
import winrt.windows.foundation.collections as windows_foundation_collections
import winrt.windows.foundation.numerics as windows_foundation_numerics
import winrt.windows.ui as windows_ui
import winrt.windows.ui.composition as windows_ui_composition
import winrt.windows.ui.core as windows_ui_core
import winrt.windows.ui.input as windows_ui_input
import winrt.windows.ui.text as windows_ui_text
import winrt.windows.ui.xaml as windows_ui_xaml
import winrt.windows.ui.xaml.controls as windows_ui_xaml_controls
import winrt.windows.ui.xaml.data as windows_ui_xaml_data
import winrt.windows.ui.xaml.input as windows_ui_xaml_input
import winrt.windows.ui.xaml.interop as windows_ui_xaml_interop
import winrt.windows.ui.xaml.media as windows_ui_xaml_media
import winrt.windows.ui.xaml.media.animation as windows_ui_xaml_media_animation
import winrt.windows.ui.xaml.media.media3d as windows_ui_xaml_media_media3d

from winrt.windows.ui.xaml.controls.primitives import AnimationDirection, ComponentResourceLocation, EdgeTransitionLocation, FlyoutPlacementMode, FlyoutShowMode, GeneratorDirection, GroupHeaderPlacement, ListViewItemPresenterCheckMode, ListViewItemPresenterSelectionIndicatorMode, PlacementMode, PopupPlacementMode, ScrollEventType, ScrollingIndicatorMode, SliderSnapsTo, SnapPointsAlignment, TickPlacement
from winrt.windows.ui.xaml.controls.primitives import DragCompletedEventHandler, DragDeltaEventHandler, DragStartedEventHandler, ItemsChangedEventHandler, RangeBaseValueChangedEventHandler, ScrollEventHandler

Self = typing.TypeVar('Self')

@typing.final
class GeneratorPosition:
    index: winrt.system.Int32
    offset: winrt.system.Int32
    def __init__(self, index: winrt.system.Int32, offset: winrt.system.Int32) -> None: ...

@typing.final
class AppBarButtonTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> AppBarButtonTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def keyboard_accelerator_text_min_width(self) -> winrt.system.Double: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class AppBarTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> AppBarTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def clip_rect(self) -> windows_foundation.Rect: ...
    @_property
    def compact_root_margin(self) -> windows_ui_xaml.Thickness: ...
    @_property
    def compact_vertical_delta(self) -> winrt.system.Double: ...
    @_property
    def hidden_root_margin(self) -> windows_ui_xaml.Thickness: ...
    @_property
    def hidden_vertical_delta(self) -> winrt.system.Double: ...
    @_property
    def minimal_root_margin(self) -> windows_ui_xaml.Thickness: ...
    @_property
    def minimal_vertical_delta(self) -> winrt.system.Double: ...
    @_property
    def negative_compact_vertical_delta(self) -> winrt.system.Double: ...
    @_property
    def negative_hidden_vertical_delta(self) -> winrt.system.Double: ...
    @_property
    def negative_minimal_vertical_delta(self) -> winrt.system.Double: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class AppBarToggleButtonTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> AppBarToggleButtonTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def keyboard_accelerator_text_min_width(self) -> winrt.system.Double: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class ButtonBase_Static(type):
    @_property
    def click_mode_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def command_parameter_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def command_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def is_pointer_over_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def is_pressed_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class ButtonBase(winrt.system.Object, metaclass=ButtonBase_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ButtonBase: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_click(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_click(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def command_parameter(self) -> typing.Optional[winrt.system.Object]: ...
    @command_parameter.setter
    def command_parameter(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def command(self) -> typing.Optional[windows_ui_xaml_input.ICommand]: ...
    @command.setter
    def command(self, value: typing.Optional[windows_ui_xaml_input.ICommand]) -> None: ...
    @_property
    def click_mode(self) -> windows_ui_xaml_controls.ClickMode: ...
    @click_mode.setter
    def click_mode(self, value: windows_ui_xaml_controls.ClickMode) -> None: ...
    @_property
    def is_pointer_over(self) -> bool: ...
    @_property
    def is_pressed(self) -> bool: ...
    @_property
    def content_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @content_transitions.setter
    def content_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def content_template_selector(self) -> typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]: ...
    @content_template_selector.setter
    def content_template_selector(self, value: typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]) -> None: ...
    @_property
    def content_template(self) -> typing.Optional[windows_ui_xaml.DataTemplate]: ...
    @content_template.setter
    def content_template(self, value: typing.Optional[windows_ui_xaml.DataTemplate]) -> None: ...
    @_property
    def content(self) -> typing.Optional[winrt.system.Object]: ...
    @content.setter
    def content(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def content_template_root(self) -> typing.Optional[windows_ui_xaml.UIElement]: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class CalendarPanel(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> CalendarPanel: ...
    def __new__(cls: typing.Type[CalendarPanel]) -> CalendarPanel: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def children_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @children_transitions.setter
    def children_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def children(self) -> typing.Optional[windows_ui_xaml_controls.UIElementCollection]: ...
    @_property
    def is_items_host(self) -> bool: ...
    @_property
    def background_transition(self) -> typing.Optional[windows_ui_xaml.BrushTransition]: ...
    @background_transition.setter
    def background_transition(self, value: typing.Optional[windows_ui_xaml.BrushTransition]) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class CalendarViewTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> CalendarViewTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def center_x(self) -> winrt.system.Double: ...
    @_property
    def center_y(self) -> winrt.system.Double: ...
    @_property
    def clip_rect(self) -> windows_foundation.Rect: ...
    @_property
    def has_more_content_after(self) -> bool: ...
    @_property
    def has_more_content_before(self) -> bool: ...
    @_property
    def has_more_views(self) -> bool: ...
    @_property
    def header_text(self) -> str: ...
    @_property
    def min_view_width(self) -> winrt.system.Double: ...
    @_property
    def week_day1(self) -> str: ...
    @_property
    def week_day2(self) -> str: ...
    @_property
    def week_day3(self) -> str: ...
    @_property
    def week_day4(self) -> str: ...
    @_property
    def week_day5(self) -> str: ...
    @_property
    def week_day6(self) -> str: ...
    @_property
    def week_day7(self) -> str: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class CarouselPanel(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> CarouselPanel: ...
    def __new__(cls: typing.Type[CarouselPanel]) -> CarouselPanel: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_irregular_snap_points(self, orientation: windows_ui_xaml_controls.Orientation, alignment: SnapPointsAlignment, /) -> typing.Optional[windows_foundation_collections.IVectorView[winrt.system.Single]]: ...
    def get_regular_snap_points(self, orientation: windows_ui_xaml_controls.Orientation, alignment: SnapPointsAlignment, /) -> typing.Tuple[winrt.system.Single, winrt.system.Single]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def line_down(self) -> None: ...
    def line_left(self) -> None: ...
    def line_right(self) -> None: ...
    def line_up(self) -> None: ...
    def make_visible(self, visual: typing.Optional[windows_ui_xaml.UIElement], rectangle: windows_foundation.Rect, /) -> windows_foundation.Rect: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def mouse_wheel_down(self) -> None: ...
    def mouse_wheel_left(self) -> None: ...
    def mouse_wheel_right(self) -> None: ...
    def mouse_wheel_up(self) -> None: ...
    def page_down(self) -> None: ...
    def page_left(self) -> None: ...
    def page_right(self) -> None: ...
    def page_up(self) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_horizontal_offset(self, offset: winrt.system.Double, /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_vertical_offset(self, offset: winrt.system.Double, /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_horizontal_snap_points_changed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_horizontal_snap_points_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_vertical_snap_points_changed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_vertical_snap_points_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def scroll_owner(self) -> typing.Optional[winrt.system.Object]: ...
    @scroll_owner.setter
    def scroll_owner(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def can_vertically_scroll(self) -> bool: ...
    @can_vertically_scroll.setter
    def can_vertically_scroll(self, value: bool) -> None: ...
    @_property
    def can_horizontally_scroll(self) -> bool: ...
    @can_horizontally_scroll.setter
    def can_horizontally_scroll(self, value: bool) -> None: ...
    @_property
    def extent_height(self) -> winrt.system.Double: ...
    @_property
    def extent_width(self) -> winrt.system.Double: ...
    @_property
    def horizontal_offset(self) -> winrt.system.Double: ...
    @_property
    def vertical_offset(self) -> winrt.system.Double: ...
    @_property
    def viewport_height(self) -> winrt.system.Double: ...
    @_property
    def viewport_width(self) -> winrt.system.Double: ...
    @_property
    def are_horizontal_snap_points_regular(self) -> bool: ...
    @_property
    def are_vertical_snap_points_regular(self) -> bool: ...
    @_property
    def item_container_generator(self) -> typing.Optional[windows_ui_xaml_controls.ItemContainerGenerator]: ...
    @_property
    def children_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @children_transitions.setter
    def children_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def children(self) -> typing.Optional[windows_ui_xaml_controls.UIElementCollection]: ...
    @_property
    def is_items_host(self) -> bool: ...
    @_property
    def background_transition(self) -> typing.Optional[windows_ui_xaml.BrushTransition]: ...
    @background_transition.setter
    def background_transition(self, value: typing.Optional[windows_ui_xaml.BrushTransition]) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class ColorPickerSlider_Static(type):
    @_property
    def color_channel_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class ColorPickerSlider(winrt.system.Object, metaclass=ColorPickerSlider_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ColorPickerSlider: ...
    def __new__(cls: typing.Type[ColorPickerSlider]) -> ColorPickerSlider: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_value_changed(self, handler: typing.Optional[RangeBaseValueChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_value_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def color_channel(self) -> windows_ui_xaml_controls.ColorPickerHsvChannel: ...
    @color_channel.setter
    def color_channel(self, value: windows_ui_xaml_controls.ColorPickerHsvChannel) -> None: ...
    @_property
    def tick_placement(self) -> TickPlacement: ...
    @tick_placement.setter
    def tick_placement(self, value: TickPlacement) -> None: ...
    @_property
    def tick_frequency(self) -> winrt.system.Double: ...
    @tick_frequency.setter
    def tick_frequency(self, value: winrt.system.Double) -> None: ...
    @_property
    def thumb_tool_tip_value_converter(self) -> typing.Optional[windows_ui_xaml_data.IValueConverter]: ...
    @thumb_tool_tip_value_converter.setter
    def thumb_tool_tip_value_converter(self, value: typing.Optional[windows_ui_xaml_data.IValueConverter]) -> None: ...
    @_property
    def step_frequency(self) -> winrt.system.Double: ...
    @step_frequency.setter
    def step_frequency(self, value: winrt.system.Double) -> None: ...
    @_property
    def snaps_to(self) -> SliderSnapsTo: ...
    @snaps_to.setter
    def snaps_to(self, value: SliderSnapsTo) -> None: ...
    @_property
    def orientation(self) -> windows_ui_xaml_controls.Orientation: ...
    @orientation.setter
    def orientation(self, value: windows_ui_xaml_controls.Orientation) -> None: ...
    @_property
    def is_thumb_tool_tip_enabled(self) -> bool: ...
    @is_thumb_tool_tip_enabled.setter
    def is_thumb_tool_tip_enabled(self, value: bool) -> None: ...
    @_property
    def is_direction_reversed(self) -> bool: ...
    @is_direction_reversed.setter
    def is_direction_reversed(self, value: bool) -> None: ...
    @_property
    def intermediate_value(self) -> winrt.system.Double: ...
    @intermediate_value.setter
    def intermediate_value(self, value: winrt.system.Double) -> None: ...
    @_property
    def header_template(self) -> typing.Optional[windows_ui_xaml.DataTemplate]: ...
    @header_template.setter
    def header_template(self, value: typing.Optional[windows_ui_xaml.DataTemplate]) -> None: ...
    @_property
    def header(self) -> typing.Optional[winrt.system.Object]: ...
    @header.setter
    def header(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def value(self) -> winrt.system.Double: ...
    @value.setter
    def value(self, value: winrt.system.Double) -> None: ...
    @_property
    def small_change(self) -> winrt.system.Double: ...
    @small_change.setter
    def small_change(self, value: winrt.system.Double) -> None: ...
    @_property
    def minimum(self) -> winrt.system.Double: ...
    @minimum.setter
    def minimum(self, value: winrt.system.Double) -> None: ...
    @_property
    def maximum(self) -> winrt.system.Double: ...
    @maximum.setter
    def maximum(self, value: winrt.system.Double) -> None: ...
    @_property
    def large_change(self) -> winrt.system.Double: ...
    @large_change.setter
    def large_change(self, value: winrt.system.Double) -> None: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class ColorSpectrum_Static(type):
    @_property
    def color_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def components_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def hsv_color_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def max_hue_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def max_saturation_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def max_value_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def min_hue_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def min_saturation_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def min_value_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def shape_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class ColorSpectrum(winrt.system.Object, metaclass=ColorSpectrum_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ColorSpectrum: ...
    def __new__(cls: typing.Type[ColorSpectrum]) -> ColorSpectrum: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_color_changed(self, handler: windows_foundation.TypedEventHandler[ColorSpectrum, windows_ui_xaml_controls.ColorChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_color_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def shape(self) -> windows_ui_xaml_controls.ColorSpectrumShape: ...
    @shape.setter
    def shape(self, value: windows_ui_xaml_controls.ColorSpectrumShape) -> None: ...
    @_property
    def min_value(self) -> winrt.system.Int32: ...
    @min_value.setter
    def min_value(self, value: winrt.system.Int32) -> None: ...
    @_property
    def min_saturation(self) -> winrt.system.Int32: ...
    @min_saturation.setter
    def min_saturation(self, value: winrt.system.Int32) -> None: ...
    @_property
    def min_hue(self) -> winrt.system.Int32: ...
    @min_hue.setter
    def min_hue(self, value: winrt.system.Int32) -> None: ...
    @_property
    def max_value(self) -> winrt.system.Int32: ...
    @max_value.setter
    def max_value(self, value: winrt.system.Int32) -> None: ...
    @_property
    def max_saturation(self) -> winrt.system.Int32: ...
    @max_saturation.setter
    def max_saturation(self, value: winrt.system.Int32) -> None: ...
    @_property
    def max_hue(self) -> winrt.system.Int32: ...
    @max_hue.setter
    def max_hue(self, value: winrt.system.Int32) -> None: ...
    @_property
    def hsv_color(self) -> windows_foundation_numerics.Vector4: ...
    @hsv_color.setter
    def hsv_color(self, value: windows_foundation_numerics.Vector4) -> None: ...
    @_property
    def components(self) -> windows_ui_xaml_controls.ColorSpectrumComponents: ...
    @components.setter
    def components(self, value: windows_ui_xaml_controls.ColorSpectrumComponents) -> None: ...
    @_property
    def color(self) -> windows_ui.Color: ...
    @color.setter
    def color(self, value: windows_ui.Color) -> None: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class ComboBoxTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ComboBoxTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def drop_down_closed_height(self) -> winrt.system.Double: ...
    @_property
    def drop_down_offset(self) -> winrt.system.Double: ...
    @_property
    def drop_down_opened_height(self) -> winrt.system.Double: ...
    @_property
    def selected_item_direction(self) -> AnimationDirection: ...
    @_property
    def drop_down_content_min_width(self) -> winrt.system.Double: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class CommandBarFlyoutCommandBar(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> CommandBarFlyoutCommandBar: ...
    def __new__(cls: typing.Type[CommandBarFlyoutCommandBar]) -> CommandBarFlyoutCommandBar: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_dynamic_overflow_items_changing(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.CommandBar, windows_ui_xaml_controls.DynamicOverflowItemsChangingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_dynamic_overflow_items_changing(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_closed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_closed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_opened(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_opened(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_closing(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_closing(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_opening(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_opening(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def flyout_template_settings(self) -> typing.Optional[CommandBarFlyoutCommandBarTemplateSettings]: ...
    @_property
    def primary_commands(self) -> typing.Optional[windows_foundation_collections.IObservableVector[windows_ui_xaml_controls.ICommandBarElement]]: ...
    @_property
    def secondary_commands(self) -> typing.Optional[windows_foundation_collections.IObservableVector[windows_ui_xaml_controls.ICommandBarElement]]: ...
    @_property
    def command_bar_overflow_presenter_style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @command_bar_overflow_presenter_style.setter
    def command_bar_overflow_presenter_style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def command_bar_template_settings(self) -> typing.Optional[CommandBarTemplateSettings]: ...
    @_property
    def overflow_button_visibility(self) -> windows_ui_xaml_controls.CommandBarOverflowButtonVisibility: ...
    @overflow_button_visibility.setter
    def overflow_button_visibility(self, value: windows_ui_xaml_controls.CommandBarOverflowButtonVisibility) -> None: ...
    @_property
    def is_dynamic_overflow_enabled(self) -> bool: ...
    @is_dynamic_overflow_enabled.setter
    def is_dynamic_overflow_enabled(self, value: bool) -> None: ...
    @_property
    def default_label_position(self) -> windows_ui_xaml_controls.CommandBarDefaultLabelPosition: ...
    @default_label_position.setter
    def default_label_position(self, value: windows_ui_xaml_controls.CommandBarDefaultLabelPosition) -> None: ...
    @_property
    def is_sticky(self) -> bool: ...
    @is_sticky.setter
    def is_sticky(self, value: bool) -> None: ...
    @_property
    def is_open(self) -> bool: ...
    @is_open.setter
    def is_open(self, value: bool) -> None: ...
    @_property
    def closed_display_mode(self) -> windows_ui_xaml_controls.AppBarClosedDisplayMode: ...
    @closed_display_mode.setter
    def closed_display_mode(self, value: windows_ui_xaml_controls.AppBarClosedDisplayMode) -> None: ...
    @_property
    def template_settings(self) -> typing.Optional[AppBarTemplateSettings]: ...
    @_property
    def light_dismiss_overlay_mode(self) -> windows_ui_xaml_controls.LightDismissOverlayMode: ...
    @light_dismiss_overlay_mode.setter
    def light_dismiss_overlay_mode(self, value: windows_ui_xaml_controls.LightDismissOverlayMode) -> None: ...
    @_property
    def content_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @content_transitions.setter
    def content_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def content_template_selector(self) -> typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]: ...
    @content_template_selector.setter
    def content_template_selector(self, value: typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]) -> None: ...
    @_property
    def content_template(self) -> typing.Optional[windows_ui_xaml.DataTemplate]: ...
    @content_template.setter
    def content_template(self, value: typing.Optional[windows_ui_xaml.DataTemplate]) -> None: ...
    @_property
    def content(self) -> typing.Optional[winrt.system.Object]: ...
    @content.setter
    def content(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def content_template_root(self) -> typing.Optional[windows_ui_xaml.UIElement]: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class CommandBarFlyoutCommandBarTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> CommandBarFlyoutCommandBarTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def close_animation_end_position(self) -> winrt.system.Double: ...
    @_property
    def content_clip_rect(self) -> windows_foundation.Rect: ...
    @_property
    def current_width(self) -> winrt.system.Double: ...
    @_property
    def expand_down_animation_end_position(self) -> winrt.system.Double: ...
    @_property
    def expand_down_animation_hold_position(self) -> winrt.system.Double: ...
    @_property
    def expand_down_animation_start_position(self) -> winrt.system.Double: ...
    @_property
    def expand_down_overflow_vertical_position(self) -> winrt.system.Double: ...
    @_property
    def expand_up_animation_end_position(self) -> winrt.system.Double: ...
    @_property
    def expand_up_animation_hold_position(self) -> winrt.system.Double: ...
    @_property
    def expand_up_animation_start_position(self) -> winrt.system.Double: ...
    @_property
    def expand_up_overflow_vertical_position(self) -> winrt.system.Double: ...
    @_property
    def expanded_width(self) -> winrt.system.Double: ...
    @_property
    def open_animation_end_position(self) -> winrt.system.Double: ...
    @_property
    def open_animation_start_position(self) -> winrt.system.Double: ...
    @_property
    def overflow_content_clip_rect(self) -> windows_foundation.Rect: ...
    @_property
    def width_expansion_animation_end_position(self) -> winrt.system.Double: ...
    @_property
    def width_expansion_animation_start_position(self) -> winrt.system.Double: ...
    @_property
    def width_expansion_delta(self) -> winrt.system.Double: ...
    @_property
    def width_expansion_more_button_animation_end_position(self) -> winrt.system.Double: ...
    @_property
    def width_expansion_more_button_animation_start_position(self) -> winrt.system.Double: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class CommandBarTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> CommandBarTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def content_height(self) -> winrt.system.Double: ...
    @_property
    def negative_overflow_content_height(self) -> winrt.system.Double: ...
    @_property
    def overflow_content_clip_rect(self) -> windows_foundation.Rect: ...
    @_property
    def overflow_content_height(self) -> winrt.system.Double: ...
    @_property
    def overflow_content_horizontal_offset(self) -> winrt.system.Double: ...
    @_property
    def overflow_content_max_height(self) -> winrt.system.Double: ...
    @_property
    def overflow_content_min_width(self) -> winrt.system.Double: ...
    @_property
    def overflow_content_max_width(self) -> winrt.system.Double: ...
    @_property
    def effective_overflow_button_visibility(self) -> windows_ui_xaml.Visibility: ...
    @_property
    def overflow_content_compact_y_translation(self) -> winrt.system.Double: ...
    @_property
    def overflow_content_hidden_y_translation(self) -> winrt.system.Double: ...
    @_property
    def overflow_content_minimal_y_translation(self) -> winrt.system.Double: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class DragCompletedEventArgs(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> DragCompletedEventArgs: ...
    def __new__(cls: typing.Type[DragCompletedEventArgs], horizontal_change: winrt.system.Double, vertical_change: winrt.system.Double, canceled: bool) -> DragCompletedEventArgs: ...
    @_property
    def canceled(self) -> bool: ...
    @_property
    def horizontal_change(self) -> winrt.system.Double: ...
    @_property
    def vertical_change(self) -> winrt.system.Double: ...
    @_property
    def original_source(self) -> typing.Optional[winrt.system.Object]: ...

@typing.final
class DragDeltaEventArgs(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> DragDeltaEventArgs: ...
    def __new__(cls: typing.Type[DragDeltaEventArgs], horizontal_change: winrt.system.Double, vertical_change: winrt.system.Double) -> DragDeltaEventArgs: ...
    @_property
    def horizontal_change(self) -> winrt.system.Double: ...
    @_property
    def vertical_change(self) -> winrt.system.Double: ...
    @_property
    def original_source(self) -> typing.Optional[winrt.system.Object]: ...

@typing.final
class DragStartedEventArgs(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> DragStartedEventArgs: ...
    def __new__(cls: typing.Type[DragStartedEventArgs], horizontal_offset: winrt.system.Double, vertical_offset: winrt.system.Double) -> DragStartedEventArgs: ...
    @_property
    def horizontal_offset(self) -> winrt.system.Double: ...
    @_property
    def vertical_offset(self) -> winrt.system.Double: ...
    @_property
    def original_source(self) -> typing.Optional[winrt.system.Object]: ...

@typing.final
class FlyoutBase_Static(type):
    def get_attached_flyout(cls, element: typing.Optional[windows_ui_xaml.FrameworkElement], /) -> typing.Optional[FlyoutBase]: ...
    def set_attached_flyout(cls, element: typing.Optional[windows_ui_xaml.FrameworkElement], value: typing.Optional[FlyoutBase], /) -> None: ...
    def show_attached_flyout(cls, flyout_owner: typing.Optional[windows_ui_xaml.FrameworkElement], /) -> None: ...
    @_property
    def attached_flyout_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def placement_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def allow_focus_on_interaction_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def allow_focus_when_disabled_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def element_sound_mode_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def light_dismiss_overlay_mode_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def overlay_input_pass_through_element_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def are_open_close_animations_enabled_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def input_device_prefers_primary_commands_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def is_open_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def show_mode_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def target_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def should_constrain_to_root_bounds_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class FlyoutBase(winrt.system.Object, metaclass=FlyoutBase_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> FlyoutBase: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def hide(self) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    @typing.overload
    def show_at(self, placement_target: typing.Optional[windows_ui_xaml.FrameworkElement], /) -> None: ...
    @typing.overload
    def show_at(self, placement_target: typing.Optional[windows_ui_xaml.DependencyObject], show_options: typing.Optional[FlyoutShowOptions], /) -> None: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def add_closed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_closed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_opened(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_opened(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_opening(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_opening(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_closing(self, handler: windows_foundation.TypedEventHandler[FlyoutBase, FlyoutBaseClosingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_closing(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def placement(self) -> FlyoutPlacementMode: ...
    @placement.setter
    def placement(self, value: FlyoutPlacementMode) -> None: ...
    @_property
    def light_dismiss_overlay_mode(self) -> windows_ui_xaml_controls.LightDismissOverlayMode: ...
    @light_dismiss_overlay_mode.setter
    def light_dismiss_overlay_mode(self, value: windows_ui_xaml_controls.LightDismissOverlayMode) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def target(self) -> typing.Optional[windows_ui_xaml.FrameworkElement]: ...
    @_property
    def overlay_input_pass_through_element(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @overlay_input_pass_through_element.setter
    def overlay_input_pass_through_element(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def show_mode(self) -> FlyoutShowMode: ...
    @show_mode.setter
    def show_mode(self, value: FlyoutShowMode) -> None: ...
    @_property
    def are_open_close_animations_enabled(self) -> bool: ...
    @are_open_close_animations_enabled.setter
    def are_open_close_animations_enabled(self, value: bool) -> None: ...
    @_property
    def input_device_prefers_primary_commands(self) -> bool: ...
    @_property
    def is_open(self) -> bool: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def should_constrain_to_root_bounds(self) -> bool: ...
    @should_constrain_to_root_bounds.setter
    def should_constrain_to_root_bounds(self, value: bool) -> None: ...
    @_property
    def is_constrained_to_root_bounds(self) -> bool: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class FlyoutBaseClosingEventArgs(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> FlyoutBaseClosingEventArgs: ...
    @_property
    def cancel(self) -> bool: ...
    @cancel.setter
    def cancel(self, value: bool) -> None: ...

@typing.final
class FlyoutShowOptions(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> FlyoutShowOptions: ...
    def __new__(cls: typing.Type[FlyoutShowOptions]) -> FlyoutShowOptions: ...
    @_property
    def show_mode(self) -> FlyoutShowMode: ...
    @show_mode.setter
    def show_mode(self, value: FlyoutShowMode) -> None: ...
    @_property
    def position(self) -> typing.Optional[typing.Optional[windows_foundation.Point]]: ...
    @position.setter
    def position(self, value: typing.Optional[typing.Optional[windows_foundation.Point]]) -> None: ...
    @_property
    def placement(self) -> FlyoutPlacementMode: ...
    @placement.setter
    def placement(self, value: FlyoutPlacementMode) -> None: ...
    @_property
    def exclusion_rect(self) -> typing.Optional[typing.Optional[windows_foundation.Rect]]: ...
    @exclusion_rect.setter
    def exclusion_rect(self, value: typing.Optional[typing.Optional[windows_foundation.Rect]]) -> None: ...

@typing.final
class GeneratorPositionHelper_Static(type):
    def from_index_and_offset(cls, index: winrt.system.Int32, offset: winrt.system.Int32, /) -> GeneratorPosition: ...

@typing.final
class GeneratorPositionHelper(winrt.system.Object, metaclass=GeneratorPositionHelper_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> GeneratorPositionHelper: ...

@typing.final
class GridViewItemPresenter_Static(type):
    @_property
    def check_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_hint_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_selecting_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def content_margin_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def disabled_opacity_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def drag_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def drag_foreground_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def drag_opacity_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def focus_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def grid_view_item_presenter_horizontal_content_alignment_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def grid_view_item_presenter_padding_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def grid_view_item_presenter_vertical_content_alignment_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def placeholder_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def pointer_over_background_margin_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def pointer_over_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def reorder_hint_offset_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_border_thickness_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_foreground_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_pointer_over_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_pointer_over_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selection_check_mark_visual_enabled_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class GridViewItemPresenter(winrt.system.Object, metaclass=GridViewItemPresenter_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> GridViewItemPresenter: ...
    def __new__(cls: typing.Type[GridViewItemPresenter]) -> GridViewItemPresenter: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def selection_check_mark_visual_enabled(self) -> bool: ...
    @selection_check_mark_visual_enabled.setter
    def selection_check_mark_visual_enabled(self, value: bool) -> None: ...
    @_property
    def selected_pointer_over_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_pointer_over_border_brush.setter
    def selected_pointer_over_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selected_pointer_over_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_pointer_over_background.setter
    def selected_pointer_over_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selected_foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_foreground.setter
    def selected_foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selected_border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @selected_border_thickness.setter
    def selected_border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def selected_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_background.setter
    def selected_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def reorder_hint_offset(self) -> winrt.system.Double: ...
    @reorder_hint_offset.setter
    def reorder_hint_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def pointer_over_background_margin(self) -> windows_ui_xaml.Thickness: ...
    @pointer_over_background_margin.setter
    def pointer_over_background_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def pointer_over_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @pointer_over_background.setter
    def pointer_over_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def placeholder_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @placeholder_background.setter
    def placeholder_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def grid_view_item_presenter_vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @grid_view_item_presenter_vertical_content_alignment.setter
    def grid_view_item_presenter_vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def grid_view_item_presenter_padding(self) -> windows_ui_xaml.Thickness: ...
    @grid_view_item_presenter_padding.setter
    def grid_view_item_presenter_padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def grid_view_item_presenter_horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @grid_view_item_presenter_horizontal_content_alignment.setter
    def grid_view_item_presenter_horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def focus_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_border_brush.setter
    def focus_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def drag_opacity(self) -> winrt.system.Double: ...
    @drag_opacity.setter
    def drag_opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def drag_foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @drag_foreground.setter
    def drag_foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def drag_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @drag_background.setter
    def drag_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def disabled_opacity(self) -> winrt.system.Double: ...
    @disabled_opacity.setter
    def disabled_opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def content_margin(self) -> windows_ui_xaml.Thickness: ...
    @content_margin.setter
    def content_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def check_selecting_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_selecting_brush.setter
    def check_selecting_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_hint_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_hint_brush.setter
    def check_hint_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_brush.setter
    def check_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def content_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @content_transitions.setter
    def content_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def content_template_selector(self) -> typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]: ...
    @content_template_selector.setter
    def content_template_selector(self, value: typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]) -> None: ...
    @_property
    def content_template(self) -> typing.Optional[windows_ui_xaml.DataTemplate]: ...
    @content_template.setter
    def content_template(self, value: typing.Optional[windows_ui_xaml.DataTemplate]) -> None: ...
    @_property
    def content(self) -> typing.Optional[winrt.system.Object]: ...
    @content.setter
    def content(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def text_line_bounds(self) -> windows_ui_xaml.TextLineBounds: ...
    @text_line_bounds.setter
    def text_line_bounds(self, value: windows_ui_xaml.TextLineBounds) -> None: ...
    @_property
    def optical_margin_alignment(self) -> windows_ui_xaml.OpticalMarginAlignment: ...
    @optical_margin_alignment.setter
    def optical_margin_alignment(self, value: windows_ui_xaml.OpticalMarginAlignment) -> None: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def text_wrapping(self) -> windows_ui_xaml.TextWrapping: ...
    @text_wrapping.setter
    def text_wrapping(self, value: windows_ui_xaml.TextWrapping) -> None: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def max_lines(self) -> winrt.system.Int32: ...
    @max_lines.setter
    def max_lines(self, value: winrt.system.Int32) -> None: ...
    @_property
    def line_stacking_strategy(self) -> windows_ui_xaml.LineStackingStrategy: ...
    @line_stacking_strategy.setter
    def line_stacking_strategy(self, value: windows_ui_xaml.LineStackingStrategy) -> None: ...
    @_property
    def line_height(self) -> winrt.system.Double: ...
    @line_height.setter
    def line_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def background_transition(self) -> typing.Optional[windows_ui_xaml.BrushTransition]: ...
    @background_transition.setter
    def background_transition(self, value: typing.Optional[windows_ui_xaml.BrushTransition]) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class GridViewItemTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> GridViewItemTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def drag_items_count(self) -> winrt.system.Int32: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class ItemsChangedEventArgs(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ItemsChangedEventArgs: ...
    @_property
    def action(self) -> winrt.system.Int32: ...
    @_property
    def item_count(self) -> winrt.system.Int32: ...
    @_property
    def item_u_i_count(self) -> winrt.system.Int32: ...
    @_property
    def old_position(self) -> GeneratorPosition: ...
    @_property
    def position(self) -> GeneratorPosition: ...

@typing.final
class JumpListItemBackgroundConverter_Static(type):
    @_property
    def disabled_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def enabled_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class JumpListItemBackgroundConverter(winrt.system.Object, metaclass=JumpListItemBackgroundConverter_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> JumpListItemBackgroundConverter: ...
    def __new__(cls: typing.Type[JumpListItemBackgroundConverter]) -> JumpListItemBackgroundConverter: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def convert(self, value: typing.Optional[winrt.system.Object], target_type: windows_ui_xaml_interop.TypeName, parameter: typing.Optional[winrt.system.Object], language: str, /) -> typing.Optional[winrt.system.Object]: ...
    def convert_back(self, value: typing.Optional[winrt.system.Object], target_type: windows_ui_xaml_interop.TypeName, parameter: typing.Optional[winrt.system.Object], language: str, /) -> typing.Optional[winrt.system.Object]: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def enabled(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @enabled.setter
    def enabled(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def disabled(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @disabled.setter
    def disabled(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class JumpListItemForegroundConverter_Static(type):
    @_property
    def disabled_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def enabled_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class JumpListItemForegroundConverter(winrt.system.Object, metaclass=JumpListItemForegroundConverter_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> JumpListItemForegroundConverter: ...
    def __new__(cls: typing.Type[JumpListItemForegroundConverter]) -> JumpListItemForegroundConverter: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def convert(self, value: typing.Optional[winrt.system.Object], target_type: windows_ui_xaml_interop.TypeName, parameter: typing.Optional[winrt.system.Object], language: str, /) -> typing.Optional[winrt.system.Object]: ...
    def convert_back(self, value: typing.Optional[winrt.system.Object], target_type: windows_ui_xaml_interop.TypeName, parameter: typing.Optional[winrt.system.Object], language: str, /) -> typing.Optional[winrt.system.Object]: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def enabled(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @enabled.setter
    def enabled(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def disabled(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @disabled.setter
    def disabled(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class LayoutInformation_Static(type):
    def get_available_size(cls, element: typing.Optional[windows_ui_xaml.UIElement], /) -> windows_foundation.Size: ...
    def get_layout_exception_element(cls, dispatcher: typing.Optional[winrt.system.Object], /) -> typing.Optional[windows_ui_xaml.UIElement]: ...
    def get_layout_slot(cls, element: typing.Optional[windows_ui_xaml.FrameworkElement], /) -> windows_foundation.Rect: ...

@typing.final
class LayoutInformation(winrt.system.Object, metaclass=LayoutInformation_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> LayoutInformation: ...

@typing.final
class ListViewItemPresenter_Static(type):
    @_property
    def selected_pointer_over_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_pointer_over_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_foreground_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_border_thickness_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def reorder_hint_offset_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def pointer_over_background_margin_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def pointer_over_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def placeholder_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def list_view_item_presenter_vertical_content_alignment_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def list_view_item_presenter_padding_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def list_view_item_presenter_horizontal_content_alignment_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def focus_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def drag_opacity_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def drag_foreground_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def drag_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def disabled_opacity_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def content_margin_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_selecting_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_hint_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selection_check_mark_visual_enabled_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def pressed_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_pressed_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def pointer_over_foreground_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def focus_secondary_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_mode_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_box_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def reveal_background_shows_above_content_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def reveal_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def reveal_border_thickness_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def reveal_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selection_indicator_pressed_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selection_indicator_pointer_over_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selection_indicator_mode_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selection_indicator_corner_radius_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selection_indicator_disabled_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selection_indicator_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_pressed_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_inner_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_disabled_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_disabled_background_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def pointer_over_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_pressed_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_disabled_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_box_selected_pressed_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_box_selected_pointer_over_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_box_selected_disabled_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_box_selected_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_box_pressed_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_box_pressed_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_box_pointer_over_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_box_pointer_over_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_box_disabled_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_box_disabled_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_box_corner_radius_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def check_box_border_brush_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selection_indicator_visual_enabled_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class ListViewItemPresenter(winrt.system.Object, metaclass=ListViewItemPresenter_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ListViewItemPresenter: ...
    def __new__(cls: typing.Type[ListViewItemPresenter]) -> ListViewItemPresenter: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def selection_check_mark_visual_enabled(self) -> bool: ...
    @selection_check_mark_visual_enabled.setter
    def selection_check_mark_visual_enabled(self, value: bool) -> None: ...
    @_property
    def selected_pointer_over_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_pointer_over_border_brush.setter
    def selected_pointer_over_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selected_pointer_over_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_pointer_over_background.setter
    def selected_pointer_over_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selected_foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_foreground.setter
    def selected_foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selected_border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @selected_border_thickness.setter
    def selected_border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def selected_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_background.setter
    def selected_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def reorder_hint_offset(self) -> winrt.system.Double: ...
    @reorder_hint_offset.setter
    def reorder_hint_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def check_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_brush.setter
    def check_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def pointer_over_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @pointer_over_background.setter
    def pointer_over_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def placeholder_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @placeholder_background.setter
    def placeholder_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def list_view_item_presenter_vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @list_view_item_presenter_vertical_content_alignment.setter
    def list_view_item_presenter_vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def list_view_item_presenter_padding(self) -> windows_ui_xaml.Thickness: ...
    @list_view_item_presenter_padding.setter
    def list_view_item_presenter_padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def list_view_item_presenter_horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @list_view_item_presenter_horizontal_content_alignment.setter
    def list_view_item_presenter_horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def focus_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_border_brush.setter
    def focus_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def drag_opacity(self) -> winrt.system.Double: ...
    @drag_opacity.setter
    def drag_opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def drag_foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @drag_foreground.setter
    def drag_foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def drag_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @drag_background.setter
    def drag_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def disabled_opacity(self) -> winrt.system.Double: ...
    @disabled_opacity.setter
    def disabled_opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def content_margin(self) -> windows_ui_xaml.Thickness: ...
    @content_margin.setter
    def content_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def check_selecting_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_selecting_brush.setter
    def check_selecting_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_hint_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_hint_brush.setter
    def check_hint_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def pointer_over_background_margin(self) -> windows_ui_xaml.Thickness: ...
    @pointer_over_background_margin.setter
    def pointer_over_background_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def selected_pressed_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_pressed_background.setter
    def selected_pressed_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def pressed_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @pressed_background.setter
    def pressed_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def pointer_over_foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @pointer_over_foreground.setter
    def pointer_over_foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_secondary_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_secondary_border_brush.setter
    def focus_secondary_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_mode(self) -> ListViewItemPresenterCheckMode: ...
    @check_mode.setter
    def check_mode(self, value: ListViewItemPresenterCheckMode) -> None: ...
    @_property
    def check_box_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_box_brush.setter
    def check_box_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def reveal_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @reveal_background.setter
    def reveal_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def reveal_background_shows_above_content(self) -> bool: ...
    @reveal_background_shows_above_content.setter
    def reveal_background_shows_above_content(self, value: bool) -> None: ...
    @_property
    def reveal_border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @reveal_border_thickness.setter
    def reveal_border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def reveal_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @reveal_border_brush.setter
    def reveal_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_disabled_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_disabled_brush.setter
    def check_disabled_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selection_indicator_pressed_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selection_indicator_pressed_brush.setter
    def selection_indicator_pressed_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selection_indicator_pointer_over_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selection_indicator_pointer_over_brush.setter
    def selection_indicator_pointer_over_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selection_indicator_mode(self) -> ListViewItemPresenterSelectionIndicatorMode: ...
    @selection_indicator_mode.setter
    def selection_indicator_mode(self, value: ListViewItemPresenterSelectionIndicatorMode) -> None: ...
    @_property
    def selection_indicator_disabled_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selection_indicator_disabled_brush.setter
    def selection_indicator_disabled_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selection_indicator_corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @selection_indicator_corner_radius.setter
    def selection_indicator_corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def selection_indicator_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selection_indicator_brush.setter
    def selection_indicator_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selected_pressed_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_pressed_border_brush.setter
    def selected_pressed_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selected_inner_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_inner_border_brush.setter
    def selected_inner_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selected_disabled_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_disabled_border_brush.setter
    def selected_disabled_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selected_disabled_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_disabled_background.setter
    def selected_disabled_background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selected_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @selected_border_brush.setter
    def selected_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def pointer_over_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @pointer_over_border_brush.setter
    def pointer_over_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_pressed_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_pressed_brush.setter
    def check_pressed_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def selection_indicator_visual_enabled(self) -> bool: ...
    @selection_indicator_visual_enabled.setter
    def selection_indicator_visual_enabled(self, value: bool) -> None: ...
    @_property
    def check_box_selected_pressed_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_box_selected_pressed_brush.setter
    def check_box_selected_pressed_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_box_selected_pointer_over_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_box_selected_pointer_over_brush.setter
    def check_box_selected_pointer_over_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_box_selected_disabled_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_box_selected_disabled_brush.setter
    def check_box_selected_disabled_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_box_selected_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_box_selected_brush.setter
    def check_box_selected_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_box_pressed_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_box_pressed_brush.setter
    def check_box_pressed_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_box_pressed_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_box_pressed_border_brush.setter
    def check_box_pressed_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_box_pointer_over_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_box_pointer_over_brush.setter
    def check_box_pointer_over_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_box_pointer_over_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_box_pointer_over_border_brush.setter
    def check_box_pointer_over_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_box_disabled_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_box_disabled_brush.setter
    def check_box_disabled_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_box_disabled_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_box_disabled_border_brush.setter
    def check_box_disabled_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def check_box_corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @check_box_corner_radius.setter
    def check_box_corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def check_box_border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @check_box_border_brush.setter
    def check_box_border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def content_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @content_transitions.setter
    def content_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def content_template_selector(self) -> typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]: ...
    @content_template_selector.setter
    def content_template_selector(self, value: typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]) -> None: ...
    @_property
    def content_template(self) -> typing.Optional[windows_ui_xaml.DataTemplate]: ...
    @content_template.setter
    def content_template(self, value: typing.Optional[windows_ui_xaml.DataTemplate]) -> None: ...
    @_property
    def content(self) -> typing.Optional[winrt.system.Object]: ...
    @content.setter
    def content(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def text_line_bounds(self) -> windows_ui_xaml.TextLineBounds: ...
    @text_line_bounds.setter
    def text_line_bounds(self, value: windows_ui_xaml.TextLineBounds) -> None: ...
    @_property
    def optical_margin_alignment(self) -> windows_ui_xaml.OpticalMarginAlignment: ...
    @optical_margin_alignment.setter
    def optical_margin_alignment(self, value: windows_ui_xaml.OpticalMarginAlignment) -> None: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def text_wrapping(self) -> windows_ui_xaml.TextWrapping: ...
    @text_wrapping.setter
    def text_wrapping(self, value: windows_ui_xaml.TextWrapping) -> None: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def max_lines(self) -> winrt.system.Int32: ...
    @max_lines.setter
    def max_lines(self, value: winrt.system.Int32) -> None: ...
    @_property
    def line_stacking_strategy(self) -> windows_ui_xaml.LineStackingStrategy: ...
    @line_stacking_strategy.setter
    def line_stacking_strategy(self, value: windows_ui_xaml.LineStackingStrategy) -> None: ...
    @_property
    def line_height(self) -> winrt.system.Double: ...
    @line_height.setter
    def line_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def background_transition(self) -> typing.Optional[windows_ui_xaml.BrushTransition]: ...
    @background_transition.setter
    def background_transition(self, value: typing.Optional[windows_ui_xaml.BrushTransition]) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class ListViewItemTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ListViewItemTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def drag_items_count(self) -> winrt.system.Int32: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class LoopingSelector_Static(type):
    @_property
    def item_height_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def item_template_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def item_width_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def items_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_index_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_item_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def should_loop_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class LoopingSelector(winrt.system.Object, metaclass=LoopingSelector_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> LoopingSelector: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_selection_changed(self, handler: typing.Optional[windows_ui_xaml_controls.SelectionChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_selection_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def should_loop(self) -> bool: ...
    @should_loop.setter
    def should_loop(self, value: bool) -> None: ...
    @_property
    def selected_item(self) -> typing.Optional[winrt.system.Object]: ...
    @selected_item.setter
    def selected_item(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def selected_index(self) -> winrt.system.Int32: ...
    @selected_index.setter
    def selected_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def items(self) -> typing.Optional[windows_foundation_collections.IVector[winrt.system.Object]]: ...
    @items.setter
    def items(self, value: typing.Optional[windows_foundation_collections.IVector[winrt.system.Object]]) -> None: ...
    @_property
    def item_width(self) -> winrt.system.Int32: ...
    @item_width.setter
    def item_width(self, value: winrt.system.Int32) -> None: ...
    @_property
    def item_template(self) -> typing.Optional[windows_ui_xaml.DataTemplate]: ...
    @item_template.setter
    def item_template(self, value: typing.Optional[windows_ui_xaml.DataTemplate]) -> None: ...
    @_property
    def item_height(self) -> winrt.system.Int32: ...
    @item_height.setter
    def item_height(self, value: winrt.system.Int32) -> None: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class LoopingSelectorItem(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> LoopingSelectorItem: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def content_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @content_transitions.setter
    def content_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def content_template_selector(self) -> typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]: ...
    @content_template_selector.setter
    def content_template_selector(self, value: typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]) -> None: ...
    @_property
    def content_template(self) -> typing.Optional[windows_ui_xaml.DataTemplate]: ...
    @content_template.setter
    def content_template(self, value: typing.Optional[windows_ui_xaml.DataTemplate]) -> None: ...
    @_property
    def content(self) -> typing.Optional[winrt.system.Object]: ...
    @content.setter
    def content(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def content_template_root(self) -> typing.Optional[windows_ui_xaml.UIElement]: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class LoopingSelectorPanel(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> LoopingSelectorPanel: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_irregular_snap_points(self, orientation: windows_ui_xaml_controls.Orientation, alignment: SnapPointsAlignment, /) -> typing.Optional[windows_foundation_collections.IVectorView[winrt.system.Single]]: ...
    def get_regular_snap_points(self, orientation: windows_ui_xaml_controls.Orientation, alignment: SnapPointsAlignment, /) -> typing.Tuple[winrt.system.Single, winrt.system.Single]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_horizontal_snap_points_changed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_horizontal_snap_points_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_vertical_snap_points_changed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_vertical_snap_points_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def are_horizontal_snap_points_regular(self) -> bool: ...
    @_property
    def are_vertical_snap_points_regular(self) -> bool: ...
    @_property
    def children_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @children_transitions.setter
    def children_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def children(self) -> typing.Optional[windows_ui_xaml_controls.UIElementCollection]: ...
    @_property
    def is_items_host(self) -> bool: ...
    @_property
    def background_transition(self) -> typing.Optional[windows_ui_xaml.BrushTransition]: ...
    @background_transition.setter
    def background_transition(self, value: typing.Optional[windows_ui_xaml.BrushTransition]) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class MenuFlyoutItemTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> MenuFlyoutItemTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def keyboard_accelerator_text_min_width(self) -> winrt.system.Double: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class MenuFlyoutPresenterTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> MenuFlyoutPresenterTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def flyout_content_min_width(self) -> winrt.system.Double: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class NavigationViewItemPresenter_Static(type):
    @_property
    def icon_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class NavigationViewItemPresenter(winrt.system.Object, metaclass=NavigationViewItemPresenter_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> NavigationViewItemPresenter: ...
    def __new__(cls: typing.Type[NavigationViewItemPresenter]) -> NavigationViewItemPresenter: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def icon(self) -> typing.Optional[windows_ui_xaml_controls.IconElement]: ...
    @icon.setter
    def icon(self, value: typing.Optional[windows_ui_xaml_controls.IconElement]) -> None: ...
    @_property
    def content_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @content_transitions.setter
    def content_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def content_template_selector(self) -> typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]: ...
    @content_template_selector.setter
    def content_template_selector(self, value: typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]) -> None: ...
    @_property
    def content_template(self) -> typing.Optional[windows_ui_xaml.DataTemplate]: ...
    @content_template.setter
    def content_template(self, value: typing.Optional[windows_ui_xaml.DataTemplate]) -> None: ...
    @_property
    def content(self) -> typing.Optional[winrt.system.Object]: ...
    @content.setter
    def content(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def content_template_root(self) -> typing.Optional[windows_ui_xaml.UIElement]: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class OrientedVirtualizingPanel(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> OrientedVirtualizingPanel: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_insertion_indexes(self, position: windows_foundation.Point, /) -> typing.Tuple[winrt.system.Int32, winrt.system.Int32]: ...
    def get_irregular_snap_points(self, orientation: windows_ui_xaml_controls.Orientation, alignment: SnapPointsAlignment, /) -> typing.Optional[windows_foundation_collections.IVectorView[winrt.system.Single]]: ...
    def get_regular_snap_points(self, orientation: windows_ui_xaml_controls.Orientation, alignment: SnapPointsAlignment, /) -> typing.Tuple[winrt.system.Single, winrt.system.Single]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def line_down(self) -> None: ...
    def line_left(self) -> None: ...
    def line_right(self) -> None: ...
    def line_up(self) -> None: ...
    def make_visible(self, visual: typing.Optional[windows_ui_xaml.UIElement], rectangle: windows_foundation.Rect, /) -> windows_foundation.Rect: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def mouse_wheel_down(self) -> None: ...
    def mouse_wheel_left(self) -> None: ...
    def mouse_wheel_right(self) -> None: ...
    def mouse_wheel_up(self) -> None: ...
    def page_down(self) -> None: ...
    def page_left(self) -> None: ...
    def page_right(self) -> None: ...
    def page_up(self) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_horizontal_offset(self, offset: winrt.system.Double, /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_vertical_offset(self, offset: winrt.system.Double, /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_horizontal_snap_points_changed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_horizontal_snap_points_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_vertical_snap_points_changed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_vertical_snap_points_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def scroll_owner(self) -> typing.Optional[winrt.system.Object]: ...
    @scroll_owner.setter
    def scroll_owner(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def can_vertically_scroll(self) -> bool: ...
    @can_vertically_scroll.setter
    def can_vertically_scroll(self, value: bool) -> None: ...
    @_property
    def can_horizontally_scroll(self) -> bool: ...
    @can_horizontally_scroll.setter
    def can_horizontally_scroll(self, value: bool) -> None: ...
    @_property
    def extent_height(self) -> winrt.system.Double: ...
    @_property
    def extent_width(self) -> winrt.system.Double: ...
    @_property
    def horizontal_offset(self) -> winrt.system.Double: ...
    @_property
    def vertical_offset(self) -> winrt.system.Double: ...
    @_property
    def viewport_height(self) -> winrt.system.Double: ...
    @_property
    def viewport_width(self) -> winrt.system.Double: ...
    @_property
    def are_horizontal_snap_points_regular(self) -> bool: ...
    @_property
    def are_vertical_snap_points_regular(self) -> bool: ...
    @_property
    def item_container_generator(self) -> typing.Optional[windows_ui_xaml_controls.ItemContainerGenerator]: ...
    @_property
    def children_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @children_transitions.setter
    def children_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def children(self) -> typing.Optional[windows_ui_xaml_controls.UIElementCollection]: ...
    @_property
    def is_items_host(self) -> bool: ...
    @_property
    def background_transition(self) -> typing.Optional[windows_ui_xaml.BrushTransition]: ...
    @background_transition.setter
    def background_transition(self, value: typing.Optional[windows_ui_xaml.BrushTransition]) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class PickerFlyoutBase_Static(type):
    def get_title(cls, element: typing.Optional[windows_ui_xaml.DependencyObject], /) -> str: ...
    def set_title(cls, element: typing.Optional[windows_ui_xaml.DependencyObject], value: str, /) -> None: ...
    @_property
    def title_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class PickerFlyoutBase(winrt.system.Object, metaclass=PickerFlyoutBase_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> PickerFlyoutBase: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def hide(self) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    @typing.overload
    def show_at(self, placement_target: typing.Optional[windows_ui_xaml.FrameworkElement], /) -> None: ...
    @typing.overload
    def show_at(self, placement_target: typing.Optional[windows_ui_xaml.DependencyObject], show_options: typing.Optional[FlyoutShowOptions], /) -> None: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def add_closed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_closed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_opened(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_opened(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_opening(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_opening(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_closing(self, handler: windows_foundation.TypedEventHandler[FlyoutBase, FlyoutBaseClosingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_closing(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def placement(self) -> FlyoutPlacementMode: ...
    @placement.setter
    def placement(self, value: FlyoutPlacementMode) -> None: ...
    @_property
    def light_dismiss_overlay_mode(self) -> windows_ui_xaml_controls.LightDismissOverlayMode: ...
    @light_dismiss_overlay_mode.setter
    def light_dismiss_overlay_mode(self, value: windows_ui_xaml_controls.LightDismissOverlayMode) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def target(self) -> typing.Optional[windows_ui_xaml.FrameworkElement]: ...
    @_property
    def overlay_input_pass_through_element(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @overlay_input_pass_through_element.setter
    def overlay_input_pass_through_element(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def show_mode(self) -> FlyoutShowMode: ...
    @show_mode.setter
    def show_mode(self, value: FlyoutShowMode) -> None: ...
    @_property
    def are_open_close_animations_enabled(self) -> bool: ...
    @are_open_close_animations_enabled.setter
    def are_open_close_animations_enabled(self, value: bool) -> None: ...
    @_property
    def input_device_prefers_primary_commands(self) -> bool: ...
    @_property
    def is_open(self) -> bool: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def should_constrain_to_root_bounds(self) -> bool: ...
    @should_constrain_to_root_bounds.setter
    def should_constrain_to_root_bounds(self, value: bool) -> None: ...
    @_property
    def is_constrained_to_root_bounds(self) -> bool: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class PivotHeaderItem(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> PivotHeaderItem: ...
    def __new__(cls: typing.Type[PivotHeaderItem]) -> PivotHeaderItem: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def content_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @content_transitions.setter
    def content_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def content_template_selector(self) -> typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]: ...
    @content_template_selector.setter
    def content_template_selector(self, value: typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]) -> None: ...
    @_property
    def content_template(self) -> typing.Optional[windows_ui_xaml.DataTemplate]: ...
    @content_template.setter
    def content_template(self, value: typing.Optional[windows_ui_xaml.DataTemplate]) -> None: ...
    @_property
    def content(self) -> typing.Optional[winrt.system.Object]: ...
    @content.setter
    def content(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def content_template_root(self) -> typing.Optional[windows_ui_xaml.UIElement]: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class PivotHeaderPanel(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> PivotHeaderPanel: ...
    def __new__(cls: typing.Type[PivotHeaderPanel]) -> PivotHeaderPanel: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def children_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @children_transitions.setter
    def children_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def children(self) -> typing.Optional[windows_ui_xaml_controls.UIElementCollection]: ...
    @_property
    def is_items_host(self) -> bool: ...
    @_property
    def background_transition(self) -> typing.Optional[windows_ui_xaml.BrushTransition]: ...
    @background_transition.setter
    def background_transition(self, value: typing.Optional[windows_ui_xaml.BrushTransition]) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class PivotPanel(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> PivotPanel: ...
    def __new__(cls: typing.Type[PivotPanel]) -> PivotPanel: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_irregular_snap_points(self, orientation: windows_ui_xaml_controls.Orientation, alignment: SnapPointsAlignment, /) -> typing.Optional[windows_foundation_collections.IVectorView[winrt.system.Single]]: ...
    def get_regular_snap_points(self, orientation: windows_ui_xaml_controls.Orientation, alignment: SnapPointsAlignment, /) -> typing.Tuple[winrt.system.Single, winrt.system.Single]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_horizontal_snap_points_changed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_horizontal_snap_points_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_vertical_snap_points_changed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_vertical_snap_points_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def are_horizontal_snap_points_regular(self) -> bool: ...
    @_property
    def are_vertical_snap_points_regular(self) -> bool: ...
    @_property
    def children_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @children_transitions.setter
    def children_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def children(self) -> typing.Optional[windows_ui_xaml_controls.UIElementCollection]: ...
    @_property
    def is_items_host(self) -> bool: ...
    @_property
    def background_transition(self) -> typing.Optional[windows_ui_xaml.BrushTransition]: ...
    @background_transition.setter
    def background_transition(self, value: typing.Optional[windows_ui_xaml.BrushTransition]) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class Popup_Static(type):
    @_property
    def child_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def child_transitions_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def horizontal_offset_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def is_light_dismiss_enabled_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def is_open_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def vertical_offset_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def light_dismiss_overlay_mode_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def should_constrain_to_root_bounds_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def desired_placement_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def placement_target_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class Popup(winrt.system.Object, metaclass=Popup_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> Popup: ...
    def __new__(cls: typing.Type[Popup]) -> Popup: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_closed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_closed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_opened(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_opened(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_placement_changed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_placement_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def vertical_offset(self) -> winrt.system.Double: ...
    @vertical_offset.setter
    def vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def is_open(self) -> bool: ...
    @is_open.setter
    def is_open(self, value: bool) -> None: ...
    @_property
    def is_light_dismiss_enabled(self) -> bool: ...
    @is_light_dismiss_enabled.setter
    def is_light_dismiss_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_offset(self) -> winrt.system.Double: ...
    @horizontal_offset.setter
    def horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def child_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @child_transitions.setter
    def child_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def child(self) -> typing.Optional[windows_ui_xaml.UIElement]: ...
    @child.setter
    def child(self, value: typing.Optional[windows_ui_xaml.UIElement]) -> None: ...
    @_property
    def light_dismiss_overlay_mode(self) -> windows_ui_xaml_controls.LightDismissOverlayMode: ...
    @light_dismiss_overlay_mode.setter
    def light_dismiss_overlay_mode(self, value: windows_ui_xaml_controls.LightDismissOverlayMode) -> None: ...
    @_property
    def should_constrain_to_root_bounds(self) -> bool: ...
    @should_constrain_to_root_bounds.setter
    def should_constrain_to_root_bounds(self, value: bool) -> None: ...
    @_property
    def is_constrained_to_root_bounds(self) -> bool: ...
    @_property
    def placement_target(self) -> typing.Optional[windows_ui_xaml.FrameworkElement]: ...
    @placement_target.setter
    def placement_target(self, value: typing.Optional[windows_ui_xaml.FrameworkElement]) -> None: ...
    @_property
    def desired_placement(self) -> PopupPlacementMode: ...
    @desired_placement.setter
    def desired_placement(self, value: PopupPlacementMode) -> None: ...
    @_property
    def actual_placement(self) -> PopupPlacementMode: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class ProgressBarTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ProgressBarTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def container_animation_end_position(self) -> winrt.system.Double: ...
    @_property
    def container_animation_start_position(self) -> winrt.system.Double: ...
    @_property
    def ellipse_animation_end_position(self) -> winrt.system.Double: ...
    @_property
    def ellipse_animation_well_position(self) -> winrt.system.Double: ...
    @_property
    def ellipse_diameter(self) -> winrt.system.Double: ...
    @_property
    def ellipse_offset(self) -> winrt.system.Double: ...
    @_property
    def indicator_length_delta(self) -> winrt.system.Double: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class ProgressRingTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ProgressRingTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def ellipse_diameter(self) -> winrt.system.Double: ...
    @_property
    def ellipse_offset(self) -> windows_ui_xaml.Thickness: ...
    @_property
    def max_side_length(self) -> winrt.system.Double: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class RangeBase_Static(type):
    @_property
    def large_change_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def maximum_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def minimum_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def small_change_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def value_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class RangeBase(winrt.system.Object, metaclass=RangeBase_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> RangeBase: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_value_changed(self, handler: typing.Optional[RangeBaseValueChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_value_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def value(self) -> winrt.system.Double: ...
    @value.setter
    def value(self, value: winrt.system.Double) -> None: ...
    @_property
    def small_change(self) -> winrt.system.Double: ...
    @small_change.setter
    def small_change(self, value: winrt.system.Double) -> None: ...
    @_property
    def minimum(self) -> winrt.system.Double: ...
    @minimum.setter
    def minimum(self, value: winrt.system.Double) -> None: ...
    @_property
    def maximum(self) -> winrt.system.Double: ...
    @maximum.setter
    def maximum(self, value: winrt.system.Double) -> None: ...
    @_property
    def large_change(self) -> winrt.system.Double: ...
    @large_change.setter
    def large_change(self, value: winrt.system.Double) -> None: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class RangeBaseValueChangedEventArgs(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> RangeBaseValueChangedEventArgs: ...
    @_property
    def new_value(self) -> winrt.system.Double: ...
    @_property
    def old_value(self) -> winrt.system.Double: ...
    @_property
    def original_source(self) -> typing.Optional[winrt.system.Object]: ...

@typing.final
class RepeatButton_Static(type):
    @_property
    def delay_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def interval_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class RepeatButton(winrt.system.Object, metaclass=RepeatButton_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> RepeatButton: ...
    def __new__(cls: typing.Type[RepeatButton]) -> RepeatButton: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_click(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_click(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def interval(self) -> winrt.system.Int32: ...
    @interval.setter
    def interval(self, value: winrt.system.Int32) -> None: ...
    @_property
    def delay(self) -> winrt.system.Int32: ...
    @delay.setter
    def delay(self, value: winrt.system.Int32) -> None: ...
    @_property
    def command_parameter(self) -> typing.Optional[winrt.system.Object]: ...
    @command_parameter.setter
    def command_parameter(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def command(self) -> typing.Optional[windows_ui_xaml_input.ICommand]: ...
    @command.setter
    def command(self, value: typing.Optional[windows_ui_xaml_input.ICommand]) -> None: ...
    @_property
    def click_mode(self) -> windows_ui_xaml_controls.ClickMode: ...
    @click_mode.setter
    def click_mode(self, value: windows_ui_xaml_controls.ClickMode) -> None: ...
    @_property
    def is_pointer_over(self) -> bool: ...
    @_property
    def is_pressed(self) -> bool: ...
    @_property
    def content_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @content_transitions.setter
    def content_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def content_template_selector(self) -> typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]: ...
    @content_template_selector.setter
    def content_template_selector(self, value: typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]) -> None: ...
    @_property
    def content_template(self) -> typing.Optional[windows_ui_xaml.DataTemplate]: ...
    @content_template.setter
    def content_template(self, value: typing.Optional[windows_ui_xaml.DataTemplate]) -> None: ...
    @_property
    def content(self) -> typing.Optional[winrt.system.Object]: ...
    @content.setter
    def content(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def content_template_root(self) -> typing.Optional[windows_ui_xaml.UIElement]: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class ScrollBar_Static(type):
    @_property
    def indicator_mode_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def orientation_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def viewport_size_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class ScrollBar(winrt.system.Object, metaclass=ScrollBar_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ScrollBar: ...
    def __new__(cls: typing.Type[ScrollBar]) -> ScrollBar: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_scroll(self, handler: typing.Optional[ScrollEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_scroll(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_value_changed(self, handler: typing.Optional[RangeBaseValueChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_value_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def viewport_size(self) -> winrt.system.Double: ...
    @viewport_size.setter
    def viewport_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def orientation(self) -> windows_ui_xaml_controls.Orientation: ...
    @orientation.setter
    def orientation(self, value: windows_ui_xaml_controls.Orientation) -> None: ...
    @_property
    def indicator_mode(self) -> ScrollingIndicatorMode: ...
    @indicator_mode.setter
    def indicator_mode(self, value: ScrollingIndicatorMode) -> None: ...
    @_property
    def value(self) -> winrt.system.Double: ...
    @value.setter
    def value(self, value: winrt.system.Double) -> None: ...
    @_property
    def small_change(self) -> winrt.system.Double: ...
    @small_change.setter
    def small_change(self, value: winrt.system.Double) -> None: ...
    @_property
    def minimum(self) -> winrt.system.Double: ...
    @minimum.setter
    def minimum(self, value: winrt.system.Double) -> None: ...
    @_property
    def maximum(self) -> winrt.system.Double: ...
    @maximum.setter
    def maximum(self, value: winrt.system.Double) -> None: ...
    @_property
    def large_change(self) -> winrt.system.Double: ...
    @large_change.setter
    def large_change(self, value: winrt.system.Double) -> None: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class ScrollEventArgs(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ScrollEventArgs: ...
    def __new__(cls: typing.Type[ScrollEventArgs]) -> ScrollEventArgs: ...
    @_property
    def new_value(self) -> winrt.system.Double: ...
    @_property
    def scroll_event_type(self) -> ScrollEventType: ...
    @_property
    def original_source(self) -> typing.Optional[winrt.system.Object]: ...

@typing.final
class Selector_Static(type):
    def get_is_selection_active(cls, element: typing.Optional[windows_ui_xaml.DependencyObject], /) -> bool: ...
    @_property
    def is_synchronized_with_current_item_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_index_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_item_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_value_path_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def selected_value_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class Selector(winrt.system.Object, metaclass=Selector_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> Selector: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def container_from_index(self, index: winrt.system.Int32, /) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    def container_from_item(self, item: typing.Optional[winrt.system.Object], /) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def group_header_container_from_item_container(self, item_container: typing.Optional[windows_ui_xaml.DependencyObject], /) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    def index_from_container(self, container: typing.Optional[windows_ui_xaml.DependencyObject], /) -> winrt.system.Int32: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def item_from_container(self, container: typing.Optional[windows_ui_xaml.DependencyObject], /) -> typing.Optional[winrt.system.Object]: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_selection_changed(self, handler: typing.Optional[windows_ui_xaml_controls.SelectionChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_selection_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def selected_value_path(self) -> str: ...
    @selected_value_path.setter
    def selected_value_path(self, value: str) -> None: ...
    @_property
    def selected_value(self) -> typing.Optional[winrt.system.Object]: ...
    @selected_value.setter
    def selected_value(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def selected_item(self) -> typing.Optional[winrt.system.Object]: ...
    @selected_item.setter
    def selected_item(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def selected_index(self) -> winrt.system.Int32: ...
    @selected_index.setter
    def selected_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def is_synchronized_with_current_item(self) -> typing.Optional[typing.Optional[bool]]: ...
    @is_synchronized_with_current_item.setter
    def is_synchronized_with_current_item(self, value: typing.Optional[typing.Optional[bool]]) -> None: ...
    @_property
    def items_source(self) -> typing.Optional[winrt.system.Object]: ...
    @items_source.setter
    def items_source(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def items_panel(self) -> typing.Optional[windows_ui_xaml_controls.ItemsPanelTemplate]: ...
    @items_panel.setter
    def items_panel(self, value: typing.Optional[windows_ui_xaml_controls.ItemsPanelTemplate]) -> None: ...
    @_property
    def item_template_selector(self) -> typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]: ...
    @item_template_selector.setter
    def item_template_selector(self, value: typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]) -> None: ...
    @_property
    def item_template(self) -> typing.Optional[windows_ui_xaml.DataTemplate]: ...
    @item_template.setter
    def item_template(self, value: typing.Optional[windows_ui_xaml.DataTemplate]) -> None: ...
    @_property
    def item_container_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @item_container_transitions.setter
    def item_container_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def item_container_style_selector(self) -> typing.Optional[windows_ui_xaml_controls.StyleSelector]: ...
    @item_container_style_selector.setter
    def item_container_style_selector(self, value: typing.Optional[windows_ui_xaml_controls.StyleSelector]) -> None: ...
    @_property
    def item_container_style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @item_container_style.setter
    def item_container_style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def group_style_selector(self) -> typing.Optional[windows_ui_xaml_controls.GroupStyleSelector]: ...
    @group_style_selector.setter
    def group_style_selector(self, value: typing.Optional[windows_ui_xaml_controls.GroupStyleSelector]) -> None: ...
    @_property
    def display_member_path(self) -> str: ...
    @display_member_path.setter
    def display_member_path(self, value: str) -> None: ...
    @_property
    def group_style(self) -> typing.Optional[windows_foundation_collections.IObservableVector[windows_ui_xaml_controls.GroupStyle]]: ...
    @_property
    def is_grouping(self) -> bool: ...
    @_property
    def item_container_generator(self) -> typing.Optional[windows_ui_xaml_controls.ItemContainerGenerator]: ...
    @_property
    def items(self) -> typing.Optional[windows_ui_xaml_controls.ItemCollection]: ...
    @_property
    def items_panel_root(self) -> typing.Optional[windows_ui_xaml_controls.Panel]: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class SelectorItem_Static(type):
    @_property
    def is_selected_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class SelectorItem(winrt.system.Object, metaclass=SelectorItem_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SelectorItem: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def is_selected(self) -> bool: ...
    @is_selected.setter
    def is_selected(self, value: bool) -> None: ...
    @_property
    def content_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @content_transitions.setter
    def content_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def content_template_selector(self) -> typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]: ...
    @content_template_selector.setter
    def content_template_selector(self, value: typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]) -> None: ...
    @_property
    def content_template(self) -> typing.Optional[windows_ui_xaml.DataTemplate]: ...
    @content_template.setter
    def content_template(self, value: typing.Optional[windows_ui_xaml.DataTemplate]) -> None: ...
    @_property
    def content(self) -> typing.Optional[winrt.system.Object]: ...
    @content.setter
    def content(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def content_template_root(self) -> typing.Optional[windows_ui_xaml.UIElement]: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class SettingsFlyoutTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SettingsFlyoutTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @_property
    def content_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @_property
    def header_background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @_property
    def header_foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @_property
    def icon_source(self) -> typing.Optional[windows_ui_xaml_media.ImageSource]: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class SplitViewTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> SplitViewTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def compact_pane_grid_length(self) -> windows_ui_xaml.GridLength: ...
    @_property
    def negative_open_pane_length(self) -> winrt.system.Double: ...
    @_property
    def negative_open_pane_length_minus_compact_length(self) -> winrt.system.Double: ...
    @_property
    def open_pane_grid_length(self) -> windows_ui_xaml.GridLength: ...
    @_property
    def open_pane_length(self) -> winrt.system.Double: ...
    @_property
    def open_pane_length_minus_compact_length(self) -> winrt.system.Double: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class Thumb_Static(type):
    @_property
    def is_dragging_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class Thumb(winrt.system.Object, metaclass=Thumb_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> Thumb: ...
    def __new__(cls: typing.Type[Thumb]) -> Thumb: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def cancel_drag(self) -> None: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_drag_completed(self, handler: typing.Optional[DragCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_delta(self, handler: typing.Optional[DragDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_started(self, handler: typing.Optional[DragStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def is_dragging(self) -> bool: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class TickBar_Static(type):
    @_property
    def fill_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class TickBar(winrt.system.Object, metaclass=TickBar_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> TickBar: ...
    def __new__(cls: typing.Type[TickBar]) -> TickBar: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def fill(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @fill.setter
    def fill(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class ToggleButton_Static(type):
    @_property
    def is_checked_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...
    @_property
    def is_three_state_property(cls) -> typing.Optional[windows_ui_xaml.DependencyProperty]: ...

@typing.final
class ToggleButton(winrt.system.Object, metaclass=ToggleButton_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ToggleButton: ...
    def __new__(cls: typing.Type[ToggleButton]) -> ToggleButton: ...
    def add_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], handled_events_too: bool, /) -> None: ...
    def apply_template(self) -> bool: ...
    def arrange(self, final_rect: windows_foundation.Rect, /) -> None: ...
    def cancel_direct_manipulations(self) -> bool: ...
    def capture_pointer(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> bool: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def find_name(self, name: str, /) -> typing.Optional[winrt.system.Object]: ...
    def focus(self, value: windows_ui_xaml.FocusState, /) -> bool: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_binding_expression(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[windows_ui_xaml_data.BindingExpression]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def invalidate_arrange(self) -> None: ...
    def invalidate_measure(self) -> None: ...
    def measure(self, available_size: windows_foundation.Size, /) -> None: ...
    def populate_property_info(self, property_name: str, property_info: typing.Optional[windows_ui_composition.AnimationPropertyInfo], /) -> None: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def release_pointer_capture(self, value: typing.Optional[windows_ui_xaml_input.Pointer], /) -> None: ...
    def release_pointer_captures(self) -> None: ...
    def remove_focus_engagement(self) -> None: ...
    def remove_handler(self, routed_event: typing.Optional[windows_ui_xaml.RoutedEvent], handler: typing.Optional[winrt.system.Object], /) -> None: ...
    def set_binding(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], binding: typing.Optional[windows_ui_xaml_data.BindingBase], /) -> None: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def start_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    @typing.overload
    def start_bring_into_view(self) -> None: ...
    @typing.overload
    def start_bring_into_view(self, options: typing.Optional[windows_ui_xaml.BringIntoViewOptions], /) -> None: ...
    def start_drag_async(self, pointer_point: typing.Optional[windows_ui_input.PointerPoint], /) -> windows_foundation.IAsyncOperation[windows_applicationmodel_datatransfer.DataPackageOperation]: ...
    def stop_animation(self, animation: typing.Optional[windows_ui_composition.ICompositionAnimationBase], /) -> None: ...
    def transform_to_visual(self, visual: typing.Optional[windows_ui_xaml.UIElement], /) -> typing.Optional[windows_ui_xaml_media.GeneralTransform]: ...
    def try_invoke_keyboard_accelerator(self, args: typing.Optional[windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    def update_layout(self) -> None: ...
    def add_checked(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_checked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_indeterminate(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_indeterminate(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unchecked(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unchecked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_click(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_click(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_is_enabled_changed(self, handler: typing.Optional[windows_ui_xaml.DependencyPropertyChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_is_enabled_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_disengaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusDisengagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_disengaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_focus_engaged(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml_controls.Control, windows_ui_xaml_controls.FocusEngagedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_focus_engaged(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_layout_updated(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_layout_updated(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_size_changed(self, handler: typing.Optional[windows_ui_xaml.SizeChangedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_size_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_unloaded(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_unloaded(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_data_context_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.DataContextChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_data_context_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_loading(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_loading(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_actual_theme_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_actual_theme_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_effective_viewport_changed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.FrameworkElement, windows_ui_xaml.EffectiveViewportChangedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_effective_viewport_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_double_tapped(self, handler: typing.Optional[windows_ui_xaml_input.DoubleTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_double_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_enter(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_enter(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_leave(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_leave(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_over(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_over(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop(self, handler: typing.Optional[windows_ui_xaml.DragEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_got_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_got_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_holding(self, handler: typing.Optional[windows_ui_xaml_input.HoldingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_holding(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_lost_focus(self, handler: typing.Optional[windows_ui_xaml.RoutedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_lost_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_completed(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationCompletedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_delta(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationDeltaEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_delta(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_inertia_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationInertiaStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_inertia_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_started(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_started(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_manipulation_starting(self, handler: typing.Optional[windows_ui_xaml_input.ManipulationStartingEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_manipulation_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_canceled(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_capture_lost(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_capture_lost(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_entered(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_entered(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_exited(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_exited(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_moved(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_moved(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_pressed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_pressed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_released(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_released(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_pointer_wheel_changed(self, handler: typing.Optional[windows_ui_xaml_input.PointerEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_pointer_wheel_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_right_tapped(self, handler: typing.Optional[windows_ui_xaml_input.RightTappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_right_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_tapped(self, handler: typing.Optional[windows_ui_xaml_input.TappedEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_tapped(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drag_starting(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DragStartingEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drag_starting(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_drop_completed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.DropCompletedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_drop_completed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_dismissed(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayDismissedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_dismissed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_display_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyDisplayRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_display_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_access_key_invoked(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.AccessKeyInvokedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_access_key_invoked(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_canceled(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.RoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_canceled(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_context_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ContextRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_context_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_getting_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.GettingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_getting_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_losing_focus(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.LosingFocusEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_losing_focus(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_no_focus_candidate_found(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.NoFocusCandidateFoundEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_no_focus_candidate_found(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_character_received(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.CharacterReceivedRoutedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_character_received(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_down(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_down(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_preview_key_up(self, handler: typing.Optional[windows_ui_xaml_input.KeyEventHandler], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_preview_key_up(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_process_keyboard_accelerators(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml_input.ProcessKeyboardAcceleratorEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_process_keyboard_accelerators(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_bring_into_view_requested(self, handler: windows_foundation.TypedEventHandler[windows_ui_xaml.UIElement, windows_ui_xaml.BringIntoViewRequestedEventArgs], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_bring_into_view_requested(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def is_three_state(self) -> bool: ...
    @is_three_state.setter
    def is_three_state(self, value: bool) -> None: ...
    @_property
    def is_checked(self) -> typing.Optional[typing.Optional[bool]]: ...
    @is_checked.setter
    def is_checked(self, value: typing.Optional[typing.Optional[bool]]) -> None: ...
    @_property
    def command_parameter(self) -> typing.Optional[winrt.system.Object]: ...
    @command_parameter.setter
    def command_parameter(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def command(self) -> typing.Optional[windows_ui_xaml_input.ICommand]: ...
    @command.setter
    def command(self, value: typing.Optional[windows_ui_xaml_input.ICommand]) -> None: ...
    @_property
    def click_mode(self) -> windows_ui_xaml_controls.ClickMode: ...
    @click_mode.setter
    def click_mode(self, value: windows_ui_xaml_controls.ClickMode) -> None: ...
    @_property
    def is_pointer_over(self) -> bool: ...
    @_property
    def is_pressed(self) -> bool: ...
    @_property
    def content_transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @content_transitions.setter
    def content_transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def content_template_selector(self) -> typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]: ...
    @content_template_selector.setter
    def content_template_selector(self, value: typing.Optional[windows_ui_xaml_controls.DataTemplateSelector]) -> None: ...
    @_property
    def content_template(self) -> typing.Optional[windows_ui_xaml.DataTemplate]: ...
    @content_template.setter
    def content_template(self, value: typing.Optional[windows_ui_xaml.DataTemplate]) -> None: ...
    @_property
    def content(self) -> typing.Optional[winrt.system.Object]: ...
    @content.setter
    def content(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def content_template_root(self) -> typing.Optional[windows_ui_xaml.UIElement]: ...
    @_property
    def padding(self) -> windows_ui_xaml.Thickness: ...
    @padding.setter
    def padding(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def is_tab_stop(self) -> bool: ...
    @is_tab_stop.setter
    def is_tab_stop(self, value: bool) -> None: ...
    @_property
    def is_enabled(self) -> bool: ...
    @is_enabled.setter
    def is_enabled(self, value: bool) -> None: ...
    @_property
    def horizontal_content_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_content_alignment.setter
    def horizontal_content_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def foreground(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @foreground.setter
    def foreground(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def font_weight(self) -> windows_ui_text.FontWeight: ...
    @font_weight.setter
    def font_weight(self, value: windows_ui_text.FontWeight) -> None: ...
    @_property
    def font_style(self) -> windows_ui_text.FontStyle: ...
    @font_style.setter
    def font_style(self, value: windows_ui_text.FontStyle) -> None: ...
    @_property
    def font_stretch(self) -> windows_ui_text.FontStretch: ...
    @font_stretch.setter
    def font_stretch(self, value: windows_ui_text.FontStretch) -> None: ...
    @_property
    def font_size(self) -> winrt.system.Double: ...
    @font_size.setter
    def font_size(self, value: winrt.system.Double) -> None: ...
    @_property
    def font_family(self) -> typing.Optional[windows_ui_xaml_media.FontFamily]: ...
    @font_family.setter
    def font_family(self, value: typing.Optional[windows_ui_xaml_media.FontFamily]) -> None: ...
    @_property
    def tab_index(self) -> winrt.system.Int32: ...
    @tab_index.setter
    def tab_index(self, value: winrt.system.Int32) -> None: ...
    @_property
    def character_spacing(self) -> winrt.system.Int32: ...
    @character_spacing.setter
    def character_spacing(self, value: winrt.system.Int32) -> None: ...
    @_property
    def border_thickness(self) -> windows_ui_xaml.Thickness: ...
    @border_thickness.setter
    def border_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def border_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @border_brush.setter
    def border_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def tab_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_navigation.setter
    def tab_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def background(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @background.setter
    def background(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def vertical_content_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_content_alignment.setter
    def vertical_content_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def template(self) -> typing.Optional[windows_ui_xaml_controls.ControlTemplate]: ...
    @template.setter
    def template(self, value: typing.Optional[windows_ui_xaml_controls.ControlTemplate]) -> None: ...
    @_property
    def focus_state(self) -> windows_ui_xaml.FocusState: ...
    @_property
    def is_text_scale_factor_enabled(self) -> bool: ...
    @is_text_scale_factor_enabled.setter
    def is_text_scale_factor_enabled(self, value: bool) -> None: ...
    @_property
    def use_system_focus_visuals(self) -> bool: ...
    @use_system_focus_visuals.setter
    def use_system_focus_visuals(self, value: bool) -> None: ...
    @_property
    def x_y_focus_up(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_up.setter
    def x_y_focus_up(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_right(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_right.setter
    def x_y_focus_right(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_left(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_left.setter
    def x_y_focus_left(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def x_y_focus_down(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @x_y_focus_down.setter
    def x_y_focus_down(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def requires_pointer(self) -> windows_ui_xaml_controls.RequiresPointer: ...
    @requires_pointer.setter
    def requires_pointer(self, value: windows_ui_xaml_controls.RequiresPointer) -> None: ...
    @_property
    def is_focus_engagement_enabled(self) -> bool: ...
    @is_focus_engagement_enabled.setter
    def is_focus_engagement_enabled(self, value: bool) -> None: ...
    @_property
    def is_focus_engaged(self) -> bool: ...
    @is_focus_engaged.setter
    def is_focus_engaged(self, value: bool) -> None: ...
    @_property
    def element_sound_mode(self) -> windows_ui_xaml.ElementSoundMode: ...
    @element_sound_mode.setter
    def element_sound_mode(self, value: windows_ui_xaml.ElementSoundMode) -> None: ...
    @_property
    def default_style_resource_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @default_style_resource_uri.setter
    def default_style_resource_uri(self, value: typing.Optional[windows_foundation.Uri]) -> None: ...
    @_property
    def corner_radius(self) -> windows_ui_xaml.CornerRadius: ...
    @corner_radius.setter
    def corner_radius(self, value: windows_ui_xaml.CornerRadius) -> None: ...
    @_property
    def background_sizing(self) -> windows_ui_xaml_controls.BackgroundSizing: ...
    @background_sizing.setter
    def background_sizing(self, value: windows_ui_xaml_controls.BackgroundSizing) -> None: ...
    @_property
    def width(self) -> winrt.system.Double: ...
    @width.setter
    def width(self, value: winrt.system.Double) -> None: ...
    @_property
    def vertical_alignment(self) -> windows_ui_xaml.VerticalAlignment: ...
    @vertical_alignment.setter
    def vertical_alignment(self, value: windows_ui_xaml.VerticalAlignment) -> None: ...
    @_property
    def tag(self) -> typing.Optional[winrt.system.Object]: ...
    @tag.setter
    def tag(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def style(self) -> typing.Optional[windows_ui_xaml.Style]: ...
    @style.setter
    def style(self, value: typing.Optional[windows_ui_xaml.Style]) -> None: ...
    @_property
    def resources(self) -> typing.Optional[windows_ui_xaml.ResourceDictionary]: ...
    @resources.setter
    def resources(self, value: typing.Optional[windows_ui_xaml.ResourceDictionary]) -> None: ...
    @_property
    def name(self) -> str: ...
    @name.setter
    def name(self, value: str) -> None: ...
    @_property
    def min_width(self) -> winrt.system.Double: ...
    @min_width.setter
    def min_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def min_height(self) -> winrt.system.Double: ...
    @min_height.setter
    def min_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_width(self) -> winrt.system.Double: ...
    @max_width.setter
    def max_width(self, value: winrt.system.Double) -> None: ...
    @_property
    def max_height(self) -> winrt.system.Double: ...
    @max_height.setter
    def max_height(self, value: winrt.system.Double) -> None: ...
    @_property
    def margin(self) -> windows_ui_xaml.Thickness: ...
    @margin.setter
    def margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def language(self) -> str: ...
    @language.setter
    def language(self, value: str) -> None: ...
    @_property
    def horizontal_alignment(self) -> windows_ui_xaml.HorizontalAlignment: ...
    @horizontal_alignment.setter
    def horizontal_alignment(self, value: windows_ui_xaml.HorizontalAlignment) -> None: ...
    @_property
    def height(self) -> winrt.system.Double: ...
    @height.setter
    def height(self, value: winrt.system.Double) -> None: ...
    @_property
    def flow_direction(self) -> windows_ui_xaml.FlowDirection: ...
    @flow_direction.setter
    def flow_direction(self, value: windows_ui_xaml.FlowDirection) -> None: ...
    @_property
    def data_context(self) -> typing.Optional[winrt.system.Object]: ...
    @data_context.setter
    def data_context(self, value: typing.Optional[winrt.system.Object]) -> None: ...
    @_property
    def actual_height(self) -> winrt.system.Double: ...
    @_property
    def actual_width(self) -> winrt.system.Double: ...
    @_property
    def base_uri(self) -> typing.Optional[windows_foundation.Uri]: ...
    @_property
    def parent(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @_property
    def triggers(self) -> typing.Optional[windows_ui_xaml.TriggerCollection]: ...
    @_property
    def requested_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @requested_theme.setter
    def requested_theme(self, value: windows_ui_xaml.ElementTheme) -> None: ...
    @_property
    def focus_visual_secondary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_secondary_thickness.setter
    def focus_visual_secondary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_secondary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_secondary_brush.setter
    def focus_visual_secondary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_primary_thickness(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_primary_thickness.setter
    def focus_visual_primary_thickness(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def focus_visual_primary_brush(self) -> typing.Optional[windows_ui_xaml_media.Brush]: ...
    @focus_visual_primary_brush.setter
    def focus_visual_primary_brush(self, value: typing.Optional[windows_ui_xaml_media.Brush]) -> None: ...
    @_property
    def focus_visual_margin(self) -> windows_ui_xaml.Thickness: ...
    @focus_visual_margin.setter
    def focus_visual_margin(self, value: windows_ui_xaml.Thickness) -> None: ...
    @_property
    def allow_focus_when_disabled(self) -> bool: ...
    @allow_focus_when_disabled.setter
    def allow_focus_when_disabled(self, value: bool) -> None: ...
    @_property
    def allow_focus_on_interaction(self) -> bool: ...
    @allow_focus_on_interaction.setter
    def allow_focus_on_interaction(self, value: bool) -> None: ...
    @_property
    def actual_theme(self) -> windows_ui_xaml.ElementTheme: ...
    @_property
    def is_loaded(self) -> bool: ...
    @_property
    def transitions(self) -> typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]: ...
    @transitions.setter
    def transitions(self, value: typing.Optional[windows_ui_xaml_media_animation.TransitionCollection]) -> None: ...
    @_property
    def projection(self) -> typing.Optional[windows_ui_xaml_media.Projection]: ...
    @projection.setter
    def projection(self, value: typing.Optional[windows_ui_xaml_media.Projection]) -> None: ...
    @_property
    def render_transform_origin(self) -> windows_foundation.Point: ...
    @render_transform_origin.setter
    def render_transform_origin(self, value: windows_foundation.Point) -> None: ...
    @_property
    def opacity(self) -> winrt.system.Double: ...
    @opacity.setter
    def opacity(self, value: winrt.system.Double) -> None: ...
    @_property
    def manipulation_mode(self) -> windows_ui_xaml_input.ManipulationModes: ...
    @manipulation_mode.setter
    def manipulation_mode(self, value: windows_ui_xaml_input.ManipulationModes) -> None: ...
    @_property
    def is_tap_enabled(self) -> bool: ...
    @is_tap_enabled.setter
    def is_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_right_tap_enabled(self) -> bool: ...
    @is_right_tap_enabled.setter
    def is_right_tap_enabled(self, value: bool) -> None: ...
    @_property
    def is_holding_enabled(self) -> bool: ...
    @is_holding_enabled.setter
    def is_holding_enabled(self, value: bool) -> None: ...
    @_property
    def is_hit_test_visible(self) -> bool: ...
    @is_hit_test_visible.setter
    def is_hit_test_visible(self, value: bool) -> None: ...
    @_property
    def is_double_tap_enabled(self) -> bool: ...
    @is_double_tap_enabled.setter
    def is_double_tap_enabled(self, value: bool) -> None: ...
    @_property
    def allow_drop(self) -> bool: ...
    @allow_drop.setter
    def allow_drop(self, value: bool) -> None: ...
    @_property
    def clip(self) -> typing.Optional[windows_ui_xaml_media.RectangleGeometry]: ...
    @clip.setter
    def clip(self, value: typing.Optional[windows_ui_xaml_media.RectangleGeometry]) -> None: ...
    @_property
    def cache_mode(self) -> typing.Optional[windows_ui_xaml_media.CacheMode]: ...
    @cache_mode.setter
    def cache_mode(self, value: typing.Optional[windows_ui_xaml_media.CacheMode]) -> None: ...
    @_property
    def use_layout_rounding(self) -> bool: ...
    @use_layout_rounding.setter
    def use_layout_rounding(self, value: bool) -> None: ...
    @_property
    def render_transform(self) -> typing.Optional[windows_ui_xaml_media.Transform]: ...
    @render_transform.setter
    def render_transform(self, value: typing.Optional[windows_ui_xaml_media.Transform]) -> None: ...
    @_property
    def visibility(self) -> windows_ui_xaml.Visibility: ...
    @visibility.setter
    def visibility(self, value: windows_ui_xaml.Visibility) -> None: ...
    @_property
    def desired_size(self) -> windows_foundation.Size: ...
    @_property
    def pointer_captures(self) -> typing.Optional[windows_foundation_collections.IVectorView[windows_ui_xaml_input.Pointer]]: ...
    @_property
    def render_size(self) -> windows_foundation.Size: ...
    @_property
    def xaml_root(self) -> typing.Optional[windows_ui_xaml.XamlRoot]: ...
    @xaml_root.setter
    def xaml_root(self, value: typing.Optional[windows_ui_xaml.XamlRoot]) -> None: ...
    @_property
    def shadow(self) -> typing.Optional[windows_ui_xaml_media.Shadow]: ...
    @shadow.setter
    def shadow(self, value: typing.Optional[windows_ui_xaml_media.Shadow]) -> None: ...
    @_property
    def actual_offset(self) -> windows_foundation_numerics.Vector3: ...
    @_property
    def actual_size(self) -> windows_foundation_numerics.Vector2: ...
    @_property
    def u_i_context(self) -> typing.Optional[windows_ui.UIContext]: ...
    @_property
    def composite_mode(self) -> windows_ui_xaml_media.ElementCompositeMode: ...
    @composite_mode.setter
    def composite_mode(self, value: windows_ui_xaml_media.ElementCompositeMode) -> None: ...
    @_property
    def transform3_d(self) -> typing.Optional[windows_ui_xaml_media_media3d.Transform3D]: ...
    @transform3_d.setter
    def transform3_d(self, value: typing.Optional[windows_ui_xaml_media_media3d.Transform3D]) -> None: ...
    @_property
    def can_drag(self) -> bool: ...
    @can_drag.setter
    def can_drag(self, value: bool) -> None: ...
    @_property
    def is_access_key_scope(self) -> bool: ...
    @is_access_key_scope.setter
    def is_access_key_scope(self, value: bool) -> None: ...
    @_property
    def exit_display_mode_on_access_key_invoked(self) -> bool: ...
    @exit_display_mode_on_access_key_invoked.setter
    def exit_display_mode_on_access_key_invoked(self, value: bool) -> None: ...
    @_property
    def context_flyout(self) -> typing.Optional[FlyoutBase]: ...
    @context_flyout.setter
    def context_flyout(self, value: typing.Optional[FlyoutBase]) -> None: ...
    @_property
    def access_key_scope_owner(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @access_key_scope_owner.setter
    def access_key_scope_owner(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def access_key(self) -> str: ...
    @access_key.setter
    def access_key(self, value: str) -> None: ...
    @_property
    def key_tip_horizontal_offset(self) -> winrt.system.Double: ...
    @key_tip_horizontal_offset.setter
    def key_tip_horizontal_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def high_contrast_adjustment(self) -> windows_ui_xaml.ElementHighContrastAdjustment: ...
    @high_contrast_adjustment.setter
    def high_contrast_adjustment(self, value: windows_ui_xaml.ElementHighContrastAdjustment) -> None: ...
    @_property
    def x_y_focus_right_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_right_navigation_strategy.setter
    def x_y_focus_right_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def x_y_focus_keyboard_navigation(self) -> windows_ui_xaml_input.XYFocusKeyboardNavigationMode: ...
    @x_y_focus_keyboard_navigation.setter
    def x_y_focus_keyboard_navigation(self, value: windows_ui_xaml_input.XYFocusKeyboardNavigationMode) -> None: ...
    @_property
    def x_y_focus_down_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_down_navigation_strategy.setter
    def x_y_focus_down_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def tab_focus_navigation(self) -> windows_ui_xaml_input.KeyboardNavigationMode: ...
    @tab_focus_navigation.setter
    def tab_focus_navigation(self, value: windows_ui_xaml_input.KeyboardNavigationMode) -> None: ...
    @_property
    def key_tip_vertical_offset(self) -> winrt.system.Double: ...
    @key_tip_vertical_offset.setter
    def key_tip_vertical_offset(self, value: winrt.system.Double) -> None: ...
    @_property
    def x_y_focus_up_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_up_navigation_strategy.setter
    def x_y_focus_up_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def key_tip_placement_mode(self) -> windows_ui_xaml_input.KeyTipPlacementMode: ...
    @key_tip_placement_mode.setter
    def key_tip_placement_mode(self, value: windows_ui_xaml_input.KeyTipPlacementMode) -> None: ...
    @_property
    def x_y_focus_left_navigation_strategy(self) -> windows_ui_xaml_input.XYFocusNavigationStrategy: ...
    @x_y_focus_left_navigation_strategy.setter
    def x_y_focus_left_navigation_strategy(self, value: windows_ui_xaml_input.XYFocusNavigationStrategy) -> None: ...
    @_property
    def lights(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_media.XamlLight]]: ...
    @_property
    def keyboard_accelerators(self) -> typing.Optional[windows_foundation_collections.IVector[windows_ui_xaml_input.KeyboardAccelerator]]: ...
    @_property
    def keyboard_accelerator_placement_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @keyboard_accelerator_placement_target.setter
    def keyboard_accelerator_placement_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def keyboard_accelerator_placement_mode(self) -> windows_ui_xaml_input.KeyboardAcceleratorPlacementMode: ...
    @keyboard_accelerator_placement_mode.setter
    def keyboard_accelerator_placement_mode(self, value: windows_ui_xaml_input.KeyboardAcceleratorPlacementMode) -> None: ...
    @_property
    def key_tip_target(self) -> typing.Optional[windows_ui_xaml.DependencyObject]: ...
    @key_tip_target.setter
    def key_tip_target(self, value: typing.Optional[windows_ui_xaml.DependencyObject]) -> None: ...
    @_property
    def translation_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @translation_transition.setter
    def translation_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def opacity_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @opacity_transition.setter
    def opacity_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def transform_matrix(self) -> windows_foundation_numerics.Matrix4x4: ...
    @transform_matrix.setter
    def transform_matrix(self, value: windows_foundation_numerics.Matrix4x4) -> None: ...
    @_property
    def scale_transition(self) -> typing.Optional[windows_ui_xaml.Vector3Transition]: ...
    @scale_transition.setter
    def scale_transition(self, value: typing.Optional[windows_ui_xaml.Vector3Transition]) -> None: ...
    @_property
    def scale(self) -> windows_foundation_numerics.Vector3: ...
    @scale.setter
    def scale(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation_transition(self) -> typing.Optional[windows_ui_xaml.ScalarTransition]: ...
    @rotation_transition.setter
    def rotation_transition(self, value: typing.Optional[windows_ui_xaml.ScalarTransition]) -> None: ...
    @_property
    def rotation_axis(self) -> windows_foundation_numerics.Vector3: ...
    @rotation_axis.setter
    def rotation_axis(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def rotation(self) -> winrt.system.Single: ...
    @rotation.setter
    def rotation(self, value: winrt.system.Single) -> None: ...
    @_property
    def translation(self) -> windows_foundation_numerics.Vector3: ...
    @translation.setter
    def translation(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def center_point(self) -> windows_foundation_numerics.Vector3: ...
    @center_point.setter
    def center_point(self, value: windows_foundation_numerics.Vector3) -> None: ...
    @_property
    def can_be_scroll_anchor(self) -> bool: ...
    @can_be_scroll_anchor.setter
    def can_be_scroll_anchor(self, value: bool) -> None: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class ToggleSwitchTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ToggleSwitchTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def curtain_current_to_off_offset(self) -> winrt.system.Double: ...
    @_property
    def curtain_current_to_on_offset(self) -> winrt.system.Double: ...
    @_property
    def curtain_off_to_on_offset(self) -> winrt.system.Double: ...
    @_property
    def curtain_on_to_off_offset(self) -> winrt.system.Double: ...
    @_property
    def knob_current_to_off_offset(self) -> winrt.system.Double: ...
    @_property
    def knob_current_to_on_offset(self) -> winrt.system.Double: ...
    @_property
    def knob_off_to_on_offset(self) -> winrt.system.Double: ...
    @_property
    def knob_on_to_off_offset(self) -> winrt.system.Double: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class ToolTipTemplateSettings(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> ToolTipTemplateSettings: ...
    def clear_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> None: ...
    def get_animation_base_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def get_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def read_local_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], /) -> typing.Optional[winrt.system.Object]: ...
    def register_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], callback: typing.Optional[windows_ui_xaml.DependencyPropertyChangedCallback], /) -> winrt.system.Int64: ...
    def set_value(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], value: typing.Optional[winrt.system.Object], /) -> None: ...
    def unregister_property_changed_callback(self, dp: typing.Optional[windows_ui_xaml.DependencyProperty], token: winrt.system.Int64, /) -> None: ...
    @_property
    def from_horizontal_offset(self) -> winrt.system.Double: ...
    @_property
    def from_vertical_offset(self) -> winrt.system.Double: ...
    @_property
    def dispatcher(self) -> typing.Optional[windows_ui_core.CoreDispatcher]: ...

@typing.final
class IScrollSnapPointsInfo(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> IScrollSnapPointsInfo: ...
    def get_irregular_snap_points(self, orientation: windows_ui_xaml_controls.Orientation, alignment: SnapPointsAlignment, /) -> typing.Optional[windows_foundation_collections.IVectorView[winrt.system.Single]]: ...
    def get_regular_snap_points(self, orientation: windows_ui_xaml_controls.Orientation, alignment: SnapPointsAlignment, /) -> typing.Tuple[winrt.system.Single, winrt.system.Single]: ...
    def add_horizontal_snap_points_changed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_horizontal_snap_points_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    def add_vertical_snap_points_changed(self, handler: windows_foundation.EventHandler[winrt.system.Object], /) -> windows_foundation.EventRegistrationToken: ...
    def remove_vertical_snap_points_changed(self, token: windows_foundation.EventRegistrationToken, /) -> None: ...
    @_property
    def are_horizontal_snap_points_regular(self) -> bool: ...
    @_property
    def are_vertical_snap_points_regular(self) -> bool: ...

